@@ -34,8 +34,12 @@ class TestCase(object):
 
     def setup_method(self, method):
         self.engine = create_engine(
-            'postgres://postgres@localhost/sqlalchemy_continuum_test'
+            'sqlite:///:memory:'
         )
+
+        # self.engine = create_engine(
+        #     'postgres://postgres@localhost/sqlalchemy_continuum_test'
+        # )
         self.connection = self.engine.connect()
         self.Model = declarative_base()
 
